/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <dirent.h>
#include <sys/stat.h>
#include <sys/types.h>
#include "appenv.h"
#include "brushes.h"
#include "colormaps.h"
#include "datafiles.h"
#include "patterns.h"
#include "pattern_header.h"
#include "pattern_select.h"
#include "brush_select.h"
#include "buildmenu.h"
#include "colormaps.h"
#include "errors.h"
#include "general.h"
#include "gimprc.h"
#include "linked.h"
#include "menus.h"


/*
 * Shared data ??
 */
GtkWidget *dialog = NULL;

static void         bp_dialog_close_callback (GtkWidget *, gpointer);
static void         bp_dialog_refresh_callback (GtkWidget *, GtkWidget *);

/*  function declarations  */

GtkWidget * 
create_bp_dialog ()
{
  GtkWidget *notebook;
  GtkWidget *label;
  GtkWidget *vbox;
  GtkWidget *brushes;
  GtkWidget *patterns;
  GtkWidget *button;

  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Brushes & Patterns");
  notebook = gtk_notebook_new ();

  vbox = gtk_vbox_new(FALSE, 1);
  gtk_box_pack_start(GTK_BOX (GTK_DIALOG(dialog)->vbox), notebook, TRUE, TRUE, 0);

  gtk_widget_show(notebook);   
  brushes = create_brush_dialog(); /* or whatever */

  label = gtk_label_new("Brushes");
  
  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5); 
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), brushes, label); 
  
  /* Likewise for the patterns part */

  patterns = create_pattern_dialog();
  label = gtk_label_new("Patterns");
  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), patterns, label);
        
  button = gtk_button_new_with_label("Close");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, TRUE,
		     TRUE, 0); 
  /* close callback */

   gtk_signal_connect(GTK_OBJECT (button), "clicked", 
		      (GtkSignalFunc) bp_dialog_close_callback,
		      NULL);

   gtk_widget_show(button);
  
  /* blah blah for the OK button */       
  button = gtk_button_new_with_label("Reload");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, TRUE,
		     TRUE, 0);   
  gtk_signal_connect(GTK_OBJECT (button), "clicked",
		     (GtkSignalFunc) bp_dialog_refresh_callback, notebook);
  

  gtk_widget_show(button); 

  
  gtk_widget_show (label);
  gtk_widget_show (notebook);
  gtk_widget_show (vbox);
  gtk_widget_show (dialog);

  gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 1);
  gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 0);
  

  return dialog;
  gdisplays_flush ();  
  
}


static void
bp_dialog_close_callback (GtkWidget *w,
			  gpointer   client_data)
{
   if (!dialog){
    return;
  }
  
  if (GTK_WIDGET_VISIBLE (dialog)){
    gtk_widget_hide (dialog);
  }
}				

static void
bp_dialog_refresh_callback (GtkWidget *w,
			    GtkWidget *the_notebook)
{
  
  if(gtk_notebook_current_page(GTK_NOTEBOOK(the_notebook))==0){
     brush_select_refresh();
  }
  else{
        pattern_select_refresh(); 
  }
}

